@@ -16,7 +16,6 @@ import pickle
 
 # For structure files of various flavor for instance POSCAR
 import ase.io
-import ipyfilechooser
 
 # =============================================
 #   Include  pycroscopy libraries                                      #
@@ -34,6 +33,7 @@ import pyTEMlib.crystal_tools
 from .config_dir import config_path
 from .sidpy_tools import *
 
+from pyTEMlib.sidpy_tools import *
 QT_available = False
 try:
     from pyTEMlib.file_tools_qt import *
@@ -276,8 +276,6 @@ def update_directory_list(directory_name):
 #  General Open and Save Methods
 ####
 
-
-
 def get_last_path():
     """Returns the path of the file last opened"""
     try:
@@ -304,172 +302,6 @@ def save_path(filename):
         path = '.'
     return path
 
-"""
-class open_file_dialog(ipyfilechooser.FileChooser):
-    def __init__(self, directory=None):
-        if directory is None:
-            directory = get_last_path()
-        super().__init__(directory) 
-        self._use_dir_icons = True
-
-    def _apply_selection(self):
-        super()._apply_selection()
-        selected = os.path.join(
-            self._selected_path,
-            self._selected_filename
-        )
-
-        if os.path.isfile(selected):
-            self._label.value = self._LBL_TEMPLATE.format(
-                self._selected_filename,
-                'blue'
-            )
-        else:
-            self._label.value = self._LBL_TEMPLATE.format(
-                self._selected_filename,
-                'green'
-            )
-        save_path(selected)
-        
-    def _set_form_values(self, path: str, filename: str):
-        ""Set the form values.""
-        # Disable triggers to prevent selecting an entry in the Select
-        # box from automatically triggering a new event.
-        self._pathlist.unobserve(
-            self._on_pathlist_select,
-            names='value'
-        )
-        self._dircontent.unobserve(
-            self._on_dircontent_select,
-            names='value'
-        )
-        self._filename.unobserve(
-            self._on_filename_change,
-            names='value'
-        )
-
-        # In folder only mode zero out the filename
-        if self._show_only_dirs:
-            filename = ''
-
-        # Set form values
-        self._pathlist.options = ipyfilechooser.utils.get_subpaths(path)
-        self._pathlist.value = path
-        self._filename.value = filename
-
-        # file/folder real names
-        dircontent_real_names = ipyfilechooser.utils.get_dir_contents(
-            path,
-            show_hidden=self._show_hidden,
-            prepend_icons=False,
-            show_only_dirs=self._show_only_dirs,
-            filter_pattern=self._filter_pattern
-        )
-
-        # file/folder 
-        names
-        dircontent_display_names = ipyfilechooser.utils.get_dir_contents(
-            path,
-            show_hidden=self._show_hidden,
-            prepend_icons=self._use_dir_icons,
-            show_only_dirs=self._show_only_dirs,
-            filter_pattern=self._filter_pattern
-        )
-        dircontent_display_names = self.set_display_names(dircontent_real_names, dircontent_display_names)
-
-        # Dict to map real names to display names
-        self._map_name_to_disp = {
-            real_name: disp_name
-            for real_name, disp_name in zip(
-                dircontent_real_names,
-                dircontent_display_names
-            )
-        }
-
-        # Dict to map display names to real names
-        self._map_disp_to_name = {
-            disp_name: real_name
-            for real_name, disp_name in
-            self._map_name_to_disp.items()
-        }
-
-        # Set _dircontent form value to display names
-        self._dircontent.options = dircontent_display_names
-
-        # If the value in the filename Text box equals a value in the
-        # Select box and the entry is a file then select the entry.
-        if ((filename in dircontent_real_names) and
-                os.path.isfile(os.path.join(path, filename))):
-            self._dircontent.value = self._map_name_to_disp[filename]
-        else:
-            self._dircontent.value = None
-
-        # Reenable triggers again
-        self._pathlist.observe(
-            self._on_pathlist_select,
-            names='value'
-        )
-        self._dircontent.observe(
-            self._on_dircontent_select,
-            names='value'
-        )
-        self._filename.observe(
-            self._on_filename_change,
-            names='value'
-        )
-
-        # Update the state of the select button
-        if self._gb.layout.display is None:
-            # Disable the select button if path and filename
-            # - equal an existing folder in the current view
-            # - equal the already selected values
-            # - don't match the provided filter pattern(s)
-            check1 = filename in dircontent_real_names
-            check2 = os.path.isdir(os.path.join(path, filename))
-            check3 = False
-            check4 = False
-
-            # Only check selected if selected is set
-            if ((self._selected_path is not None) and
-                    (self._selected_filename is not None)):
-                selected = os.path.join(
-                    self._selected_path,
-                    self._selected_filename
-                )
-                check3 = os.path.join(path, filename) == selected
-
-            # Ensure only allowed extensions are used
-            if self._filter_pattern:
-                check4 = not ipyfilechooser.utils.match_item(filename, self._filter_pattern)
-
-            if (check1 and check2) or check3 or check4:
-                self._select.disabled = True
-            else:
-                self._select.disabled = False
-    
-    def set_display_names(self, dircontent_real_names, dircontent_display_names):
-        
-        for i in range(len(dircontent_display_names)):
-            name = dircontent_display_names[i]
-            full_name = os.path.join(self._pathlist.value, dircontent_real_names[i])
-            if os.path.isfile(full_name):
-                size = os.path.getsize(full_name) * 2 ** -20
-                basename, extension = os.path.splitext(name)
-                if extension in ['.hf5']:
-                    dircontent_display_names[i] = f" {dircontent_display_names[i]:50}  -- {size:.1f} MB"
-                
-                elif extension in ['.h5', '.ndata']:
-                    try:
-                        reader = SciFiReaders.NionReader(full_name)
-                        dataset_nion = reader.read()
-                        dircontent_display_names[i] = f"   {dataset_nion.title+extension:50}  - {size:.1f} MB"
-                    except IOError:
-                        dircontent_display_names[i] = dircontent_display_names[i]
-                else:
-                    dircontent_display_names[i] = dircontent_display_names[i]
-            
-        return dircontent_display_names"""
-
     
 def open_file_dialog_qt(file_types=None):  # , multiple_files=False):
     """Opens a File dialog which is used in open_file() function
